==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/deployment/impl/TerminatorServiceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.deployment.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorService;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceParameterSet;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceSet;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorSet;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ImplementationScope;
import ooaofooa.datatypes.ParseStatus;


public class TerminatorServiceSetImpl extends InstanceSet<TerminatorServiceSet,TerminatorService> implements TerminatorServiceSet {

    // attributes
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setName( m_Name );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setDescrip( m_Descrip );
    }
    @Override
    public void setReturn_Dimensions( String m_Return_Dimensions ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setReturn_Dimensions( m_Return_Dimensions );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setSvc_ID( UniqueId m_Svc_ID ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setSvc_ID( m_Svc_ID );
    }
    @Override
    public void setTerm_ID( UniqueId ref_Term_ID ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setTerm_ID( ref_Term_ID );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setDialect( m_Dialect );
    }
    @Override
    public void setIs_Stale( boolean m_Is_Stale ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setIs_Stale( m_Is_Stale );
    }
    @Override
    public void setImplementation_Scope( ImplementationScope m_Implementation_Scope ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setImplementation_Scope( m_Implementation_Scope );
    }


    // selections
    @Override
    public TerminatorSet R1651_Terminator() throws XtumlException {
        TerminatorSet terminatorset = new TerminatorSetImpl();
        for ( TerminatorService terminatorservice : this ) terminatorset.add( terminatorservice.R1651_Terminator() );
        return terminatorset;
    }
    @Override
    public TerminatorServiceParameterSet R1652_TerminatorServiceParameter() throws XtumlException {
        TerminatorServiceParameterSet terminatorserviceparameterset = new TerminatorServiceParameterSetImpl();
        for ( TerminatorService terminatorservice : this ) terminatorserviceparameterset.addAll( terminatorservice.R1652_TerminatorServiceParameter() );
        return terminatorserviceparameterset;
    }
    @Override
    public DataTypeSet R1656_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( TerminatorService terminatorservice : this ) datatypeset.add( terminatorservice.R1656_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R1657_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( TerminatorService terminatorservice : this ) dimensionsset.addAll( terminatorservice.R1657_Dimensions() );
        return dimensionsset;
    }


    @Override
    public TerminatorService nullElement() {
        return TerminatorServiceImpl.EMPTY_TERMINATORSERVICE;
    }

    @Override
    public TerminatorServiceSet emptySet() {
      return new TerminatorServiceSetImpl();
    }

    @Override
    public TerminatorServiceSet value() {
        return this;
    }

    @Override
    public List<TerminatorService> elements() {
        TerminatorService[] elements = toArray(new TerminatorService[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/deployment/impl/TerminatorServiceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.deployment.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorService;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceParameterSet;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceSet;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorSet;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ImplementationScope;
import ooaofooa.datatypes.ParseStatus;


public class TerminatorServiceSetImpl extends InstanceSet<TerminatorServiceSet,TerminatorService> implements TerminatorServiceSet {

    public TerminatorServiceSetImpl() {
    }

    public TerminatorServiceSetImpl(Comparator<? super TerminatorService> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setName( m_Name );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setTerm_ID( UniqueId ref_Term_ID ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setTerm_ID( ref_Term_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setDescrip( m_Descrip );
    }
    @Override
    public void setIs_Stale( boolean m_Is_Stale ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setIs_Stale( m_Is_Stale );
    }
    @Override
    public void setImplementation_Scope( ImplementationScope m_Implementation_Scope ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setImplementation_Scope( m_Implementation_Scope );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setSvc_ID( UniqueId m_Svc_ID ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setSvc_ID( m_Svc_ID );
    }
    @Override
    public void setReturn_Dimensions( String m_Return_Dimensions ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setReturn_Dimensions( m_Return_Dimensions );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( TerminatorService terminatorservice : this ) terminatorservice.setDialect( m_Dialect );
    }


    // selections
    @Override
    public TerminatorSet R1651_Terminator() throws XtumlException {
        TerminatorSet terminatorset = new TerminatorSetImpl();
        for ( TerminatorService terminatorservice : this ) terminatorset.add( terminatorservice.R1651_Terminator() );
        return terminatorset;
    }
    @Override
    public TerminatorServiceParameterSet R1652_TerminatorServiceParameter() throws XtumlException {
        TerminatorServiceParameterSet terminatorserviceparameterset = new TerminatorServiceParameterSetImpl();
        for ( TerminatorService terminatorservice : this ) terminatorserviceparameterset.addAll( terminatorservice.R1652_TerminatorServiceParameter() );
        return terminatorserviceparameterset;
    }
    @Override
    public DataTypeSet R1656_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( TerminatorService terminatorservice : this ) datatypeset.add( terminatorservice.R1656_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R1657_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( TerminatorService terminatorservice : this ) dimensionsset.addAll( terminatorservice.R1657_Dimensions() );
        return dimensionsset;
    }


    @Override
    public TerminatorService nullElement() {
        return TerminatorServiceImpl.EMPTY_TERMINATORSERVICE;
    }

    @Override
    public TerminatorServiceSet emptySet() {
      return new TerminatorServiceSetImpl();
    }

    @Override
    public TerminatorServiceSet emptySet(Comparator<? super TerminatorService> comp) {
      return new TerminatorServiceSetImpl(comp);
    }

    @Override
    public TerminatorServiceSet value() {
        return this;
    }

    @Override
    public List<TerminatorService> elements() {
        TerminatorService[] elements = toArray(new TerminatorService[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
